# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Chat Service."""

__version__ = "0.4.29"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_add_topic_member import AdminAddTopicMember
from .admin_ban_topic_members import AdminBanTopicMembers
from .admin_channel_topic_info import AdminChannelTopicInfo
from .admin_channel_topic_list import AdminChannelTopicList
from .admin_channel_topic_summary import AdminChannelTopicSummary
from .admin_chat_history import AdminChatHistory
from .admin_create_namespace_topic import AdminCreateNamespaceTopic
from .admin_create_topic import AdminCreateTopic
from .admin_delete_chat import AdminDeleteChat
from .admin_delete_topic import AdminDeleteTopic
from .admin_filter_chat_message import AdminFilterChatMessage
from .admin_query_topic import AdminQueryTopic
from .admin_query_topic import (
    TopicSubTypeEnum as AdminQueryTopicTopicSubTypeEnum,
    TopicTypeEnum as AdminQueryTopicTopicTypeEnum,
)
from .admin_query_topic_log import AdminQueryTopicLog
from .admin_query_users_topic import AdminQueryUsersTopic
from .admin_query_users_topic import (
    TopicSubTypeEnum as AdminQueryUsersTopicTopicSubTypeEnum,
    TopicTypeEnum as AdminQueryUsersTopicTopicTypeEnum,
)
from .admin_remove_topic_member import AdminRemoveTopicMember
from .admin_send_chat import AdminSendChat
from .admin_topic_chat_history import AdminTopicChatHistory
from .admin_topic_list import AdminTopicList
from .admin_topic_members import AdminTopicMembers
from .admin_topic_shards import AdminTopicShards
from .admin_unban_topic_members import AdminUnbanTopicMembers
from .admin_update_topic import AdminUpdateTopic
from .public_ban_topic_members import PublicBanTopicMembers
from .public_chat_history import PublicChatHistory
from .public_delete_chat import PublicDeleteChat
from .public_get_muted_topics import PublicGetMutedTopics
from .public_mute_user import PublicMuteUser
from .public_topic_list import PublicTopicList
from .public_unban_topic_members import PublicUnbanTopicMembers
from .public_unmute_user import PublicUnmuteUser



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Platform Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum


class ComparisonEnum(StrEnum):
    EXCLUDES = "excludes"
    INCLUDES = "includes"
    IS = "is"
    ISGREATERTHAN = "isGreaterThan"
    ISGREATERTHANOREQUAL = "isGreaterThanOrEqual"
    ISLESSTHAN = "isLessThan"
    ISLESSTHANOREQUAL = "isLessThanOrEqual"
    ISNOT = "isNot"


class PredicateTypeEnum(StrEnum):
    ENTITLEMENTPREDICATE = "EntitlementPredicate"
    SEASONPASSPREDICATE = "SeasonPassPredicate"
    SEASONTIERPREDICATE = "SeasonTierPredicate"


class Predicate(Model):
    """predicate object (Predicate)

    Properties:
        any_of: (anyOf) OPTIONAL int

        comparison: (comparison) OPTIONAL Union[str, ComparisonEnum]

        name: (name) OPTIONAL str

        predicate_type: (predicateType) OPTIONAL Union[str, PredicateTypeEnum]

        value: (value) OPTIONAL str

        values: (values) OPTIONAL List[str]
    """

    # region fields

    any_of: int  # OPTIONAL
    comparison: Union[str, ComparisonEnum]  # OPTIONAL
    name: str  # OPTIONAL
    predicate_type: Union[str, PredicateTypeEnum]  # OPTIONAL
    value: str  # OPTIONAL
    values: List[str]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_any_of(self, value: int) -> Predicate:
        self.any_of = value
        return self

    def with_comparison(self, value: Union[str, ComparisonEnum]) -> Predicate:
        self.comparison = value
        return self

    def with_name(self, value: str) -> Predicate:
        self.name = value
        return self

    def with_predicate_type(self, value: Union[str, PredicateTypeEnum]) -> Predicate:
        self.predicate_type = value
        return self

    def with_value(self, value: str) -> Predicate:
        self.value = value
        return self

    def with_values(self, value: List[str]) -> Predicate:
        self.values = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "any_of"):
            result["anyOf"] = int(self.any_of)
        elif include_empty:
            result["anyOf"] = 0
        if hasattr(self, "comparison"):
            result["comparison"] = str(self.comparison)
        elif include_empty:
            result["comparison"] = Union[str, ComparisonEnum]()
        if hasattr(self, "name"):
            result["name"] = str(self.name)
        elif include_empty:
            result["name"] = ""
        if hasattr(self, "predicate_type"):
            result["predicateType"] = str(self.predicate_type)
        elif include_empty:
            result["predicateType"] = Union[str, PredicateTypeEnum]()
        if hasattr(self, "value"):
            result["value"] = str(self.value)
        elif include_empty:
            result["value"] = ""
        if hasattr(self, "values"):
            result["values"] = [str(i0) for i0 in self.values]
        elif include_empty:
            result["values"] = []
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        any_of: Optional[int] = None,
        comparison: Optional[Union[str, ComparisonEnum]] = None,
        name: Optional[str] = None,
        predicate_type: Optional[Union[str, PredicateTypeEnum]] = None,
        value: Optional[str] = None,
        values: Optional[List[str]] = None,
        **kwargs,
    ) -> Predicate:
        instance = cls()
        if any_of is not None:
            instance.any_of = any_of
        if comparison is not None:
            instance.comparison = comparison
        if name is not None:
            instance.name = name
        if predicate_type is not None:
            instance.predicate_type = predicate_type
        if value is not None:
            instance.value = value
        if values is not None:
            instance.values = values
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> Predicate:
        instance = cls()
        if not dict_:
            return instance
        if "anyOf" in dict_ and dict_["anyOf"] is not None:
            instance.any_of = int(dict_["anyOf"])
        elif include_empty:
            instance.any_of = 0
        if "comparison" in dict_ and dict_["comparison"] is not None:
            instance.comparison = str(dict_["comparison"])
        elif include_empty:
            instance.comparison = Union[str, ComparisonEnum]()
        if "name" in dict_ and dict_["name"] is not None:
            instance.name = str(dict_["name"])
        elif include_empty:
            instance.name = ""
        if "predicateType" in dict_ and dict_["predicateType"] is not None:
            instance.predicate_type = str(dict_["predicateType"])
        elif include_empty:
            instance.predicate_type = Union[str, PredicateTypeEnum]()
        if "value" in dict_ and dict_["value"] is not None:
            instance.value = str(dict_["value"])
        elif include_empty:
            instance.value = ""
        if "values" in dict_ and dict_["values"] is not None:
            instance.values = [str(i0) for i0 in dict_["values"]]
        elif include_empty:
            instance.values = []
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, Predicate]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[Predicate]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[Predicate, List[Predicate], Dict[Any, Predicate]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "anyOf": "any_of",
            "comparison": "comparison",
            "name": "name",
            "predicateType": "predicate_type",
            "value": "value",
            "values": "values",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "anyOf": False,
            "comparison": False,
            "name": False,
            "predicateType": False,
            "value": False,
            "values": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "comparison": [
                "excludes",
                "includes",
                "is",
                "isGreaterThan",
                "isGreaterThanOrEqual",
                "isLessThan",
                "isLessThanOrEqual",
                "isNot",
            ],
            "predicateType": [
                "EntitlementPredicate",
                "SeasonPassPredicate",
                "SeasonTierPredicate",
            ],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Platform Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum

from ..models.credit_revocation import CreditRevocation
from ..models.entitlement_revocation import EntitlementRevocation
from ..models.item_revocation import ItemRevocation


class StatusEnum(StrEnum):
    FAIL = "FAIL"
    SUCCESS = "SUCCESS"


class RevocationResult(Model):
    """Revocation result (RevocationResult)

    Properties:
        id_: (id) REQUIRED str

        status: (status) REQUIRED Union[str, StatusEnum]

        credit_revocations: (creditRevocations) OPTIONAL List[CreditRevocation]

        entitlement_revocations: (entitlementRevocations) OPTIONAL List[EntitlementRevocation]

        item_revocations: (itemRevocations) OPTIONAL List[ItemRevocation]
    """

    # region fields

    id_: str  # REQUIRED
    status: Union[str, StatusEnum]  # REQUIRED
    credit_revocations: List[CreditRevocation]  # OPTIONAL
    entitlement_revocations: List[EntitlementRevocation]  # OPTIONAL
    item_revocations: List[ItemRevocation]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_id(self, value: str) -> RevocationResult:
        self.id_ = value
        return self

    def with_status(self, value: Union[str, StatusEnum]) -> RevocationResult:
        self.status = value
        return self

    def with_credit_revocations(
        self, value: List[CreditRevocation]
    ) -> RevocationResult:
        self.credit_revocations = value
        return self

    def with_entitlement_revocations(
        self, value: List[EntitlementRevocation]
    ) -> RevocationResult:
        self.entitlement_revocations = value
        return self

    def with_item_revocations(self, value: List[ItemRevocation]) -> RevocationResult:
        self.item_revocations = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "id_"):
            result["id"] = str(self.id_)
        elif include_empty:
            result["id"] = ""
        if hasattr(self, "status"):
            result["status"] = str(self.status)
        elif include_empty:
            result["status"] = Union[str, StatusEnum]()
        if hasattr(self, "credit_revocations"):
            result["creditRevocations"] = [
                i0.to_dict(include_empty=include_empty)
                for i0 in self.credit_revocations
            ]
        elif include_empty:
            result["creditRevocations"] = []
        if hasattr(self, "entitlement_revocations"):
            result["entitlementRevocations"] = [
                i0.to_dict(include_empty=include_empty)
                for i0 in self.entitlement_revocations
            ]
        elif include_empty:
            result["entitlementRevocations"] = []
        if hasattr(self, "item_revocations"):
            result["itemRevocations"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.item_revocations
            ]
        elif include_empty:
            result["itemRevocations"] = []
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        id_: str,
        status: Union[str, StatusEnum],
        credit_revocations: Optional[List[CreditRevocation]] = None,
        entitlement_revocations: Optional[List[EntitlementRevocation]] = None,
        item_revocations: Optional[List[ItemRevocation]] = None,
        **kwargs,
    ) -> RevocationResult:
        instance = cls()
        instance.id_ = id_
        instance.status = status
        if credit_revocations is not None:
            instance.credit_revocations = credit_revocations
        if entitlement_revocations is not None:
            instance.entitlement_revocations = entitlement_revocations
        if item_revocations is not None:
            instance.item_revocations = item_revocations
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> RevocationResult:
        instance = cls()
        if not dict_:
            return instance
        if "id" in dict_ and dict_["id"] is not None:
            instance.id_ = str(dict_["id"])
        elif include_empty:
            instance.id_ = ""
        if "status" in dict_ and dict_["status"] is not None:
            instance.status = str(dict_["status"])
        elif include_empty:
            instance.status = Union[str, StatusEnum]()
        if "creditRevocations" in dict_ and dict_["creditRevocations"] is not None:
            instance.credit_revocations = [
                CreditRevocation.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["creditRevocations"]
            ]
        elif include_empty:
            instance.credit_revocations = []
        if (
            "entitlementRevocations" in dict_
            and dict_["entitlementRevocations"] is not None
        ):
            instance.entitlement_revocations = [
                EntitlementRevocation.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["entitlementRevocations"]
            ]
        elif include_empty:
            instance.entitlement_revocations = []
        if "itemRevocations" in dict_ and dict_["itemRevocations"] is not None:
            instance.item_revocations = [
                ItemRevocation.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["itemRevocations"]
            ]
        elif include_empty:
            instance.item_revocations = []
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, RevocationResult]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[RevocationResult]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[RevocationResult, List[RevocationResult], Dict[Any, RevocationResult]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "id": "id_",
            "status": "status",
            "creditRevocations": "credit_revocations",
            "entitlementRevocations": "entitlement_revocations",
            "itemRevocations": "item_revocations",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "id": True,
            "status": True,
            "creditRevocations": False,
            "entitlementRevocations": False,
            "itemRevocations": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "status": ["FAIL", "SUCCESS"],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelsBlockPlayerRequest
from ..models import ModelsGetAllPlayerBlockedByUsersResponse
from ..models import ModelsGetAllPlayerBlockedUsersResponse
from ..models import ModelsGetAllPlayerSessionAttributeResponse
from ..models import ModelsGetBulkAllPlayerBlockedUsersRequest
from ..models import ModelsGetBulkAllPlayerBlockedUsersResponse
from ..models import ModelsGetLobbyCcuResponse
from ..models import ModelsGetPlayerSessionAttributeResponse
from ..models import ModelsListBlockedPlayerRequest
from ..models import ModelsSetPlayerSessionAttributeRequest
from ..models import ModelsUnblockPlayerRequest
from ..models import RestapiErrorResponseBody

from ..operations.player import AdminBulkBlockPlayersV1
from ..operations.player import AdminGetAllPlayerSessionAttribute
from ..operations.player import AdminGetBulkPlayerBlockedPlayersV1
from ..operations.player import AdminGetLobbyCCU
from ..operations.player import AdminGetPlayerBlockedByPlayersV1
from ..operations.player import AdminGetPlayerBlockedPlayersV1
from ..operations.player import AdminGetPlayerSessionAttribute
from ..operations.player import AdminSetPlayerSessionAttribute
from ..operations.player import PublicGetPlayerBlockedByPlayersV1
from ..operations.player import PublicGetPlayerBlockedPlayersV1
from ..operations.player import PublicPlayerBlockPlayersV1
from ..operations.player import PublicUnblockPlayerV1


@same_doc_as(AdminBulkBlockPlayersV1)
def admin_bulk_block_players_v1(
    body: ModelsListBlockedPlayerRequest,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Admin bulk blocks player by list user id (adminBulkBlockPlayersV1)

    Bulk block player in a namespace by list of user id

    Properties:
        url: /lobby/v1/admin/player/namespaces/{namespace}/users/{userId}/bulk/block

        method: POST

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsListBlockedPlayerRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminBulkBlockPlayersV1.create(
        body=body,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminBulkBlockPlayersV1)
async def admin_bulk_block_players_v1_async(
    body: ModelsListBlockedPlayerRequest,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Admin bulk blocks player by list user id (adminBulkBlockPlayersV1)

    Bulk block player in a namespace by list of user id

    Properties:
        url: /lobby/v1/admin/player/namespaces/{namespace}/users/{userId}/bulk/block

        method: POST

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsListBlockedPlayerRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminBulkBlockPlayersV1.create(
        body=body,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetAllPlayerSessionAttribute)
def admin_get_all_player_session_attribute(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get all player's session attribute (adminGetAllPlayerSessionAttribute)

    Get all player's session attribute by user id in a namespace.

    Properties:
        url: /lobby/v1/admin/player/namespaces/{namespace}/users/{userId}/attributes

        method: GET

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsGetAllPlayerSessionAttributeResponse (OK)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetAllPlayerSessionAttribute.create(
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetAllPlayerSessionAttribute)
async def admin_get_all_player_session_attribute_async(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get all player's session attribute (adminGetAllPlayerSessionAttribute)

    Get all player's session attribute by user id in a namespace.

    Properties:
        url: /lobby/v1/admin/player/namespaces/{namespace}/users/{userId}/attributes

        method: GET

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsGetAllPlayerSessionAttributeResponse (OK)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetAllPlayerSessionAttribute.create(
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetBulkPlayerBlockedPlayersV1)
def admin_get_bulk_player_blocked_players_v1(
    body: ModelsGetBulkAllPlayerBlockedUsersRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get blocked players by bulk user ids (adminGetBulkPlayerBlockedPlayersV1)

    Get blocked players data by bulk user ids in a namespace.

    Properties:
        url: /lobby/v1/admin/player/namespaces/{namespace}/users/bulk/blocked

        method: POST

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsGetBulkAllPlayerBlockedUsersRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsGetBulkAllPlayerBlockedUsersResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetBulkPlayerBlockedPlayersV1.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetBulkPlayerBlockedPlayersV1)
async def admin_get_bulk_player_blocked_players_v1_async(
    body: ModelsGetBulkAllPlayerBlockedUsersRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get blocked players by bulk user ids (adminGetBulkPlayerBlockedPlayersV1)

    Get blocked players data by bulk user ids in a namespace.

    Properties:
        url: /lobby/v1/admin/player/namespaces/{namespace}/users/bulk/blocked

        method: POST

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsGetBulkAllPlayerBlockedUsersRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsGetBulkAllPlayerBlockedUsersResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetBulkPlayerBlockedPlayersV1.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetLobbyCCU)
def admin_get_lobby_ccu(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get number of players currently connected to the lobby. (adminGetLobbyCCU)

    Get the number of players connected to the Lobby in the given namespace.

    Properties:
        url: /lobby/v1/admin/player/namespaces/{namespace}/ccu

        method: GET

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsGetLobbyCcuResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetLobbyCCU.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetLobbyCCU)
async def admin_get_lobby_ccu_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get number of players currently connected to the lobby. (adminGetLobbyCCU)

    Get the number of players connected to the Lobby in the given namespace.

    Properties:
        url: /lobby/v1/admin/player/namespaces/{namespace}/ccu

        method: GET

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsGetLobbyCcuResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetLobbyCCU.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetPlayerBlockedByPlayersV1)
def admin_get_player_blocked_by_players_v1(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get players who blocked this player by user id (adminGetPlayerBlockedByPlayersV1)

    Load get players who blocked this player in a namespace based on user id

    Properties:
        url: /lobby/v1/admin/player/namespaces/{namespace}/users/{userId}/blocked-by

        method: GET

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsGetAllPlayerBlockedByUsersResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetPlayerBlockedByPlayersV1.create(
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetPlayerBlockedByPlayersV1)
async def admin_get_player_blocked_by_players_v1_async(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get players who blocked this player by user id (adminGetPlayerBlockedByPlayersV1)

    Load get players who blocked this player in a namespace based on user id

    Properties:
        url: /lobby/v1/admin/player/namespaces/{namespace}/users/{userId}/blocked-by

        method: GET

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsGetAllPlayerBlockedByUsersResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetPlayerBlockedByPlayersV1.create(
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetPlayerBlockedPlayersV1)
def admin_get_player_blocked_players_v1(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get blocked players by user id (adminGetPlayerBlockedPlayersV1)

    Get blocked players data by user id in a namespace.

    Properties:
        url: /lobby/v1/admin/player/namespaces/{namespace}/users/{userId}/blocked

        method: GET

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsGetAllPlayerBlockedUsersResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetPlayerBlockedPlayersV1.create(
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetPlayerBlockedPlayersV1)
async def admin_get_player_blocked_players_v1_async(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get blocked players by user id (adminGetPlayerBlockedPlayersV1)

    Get blocked players data by user id in a namespace.

    Properties:
        url: /lobby/v1/admin/player/namespaces/{namespace}/users/{userId}/blocked

        method: GET

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsGetAllPlayerBlockedUsersResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetPlayerBlockedPlayersV1.create(
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetPlayerSessionAttribute)
def admin_get_player_session_attribute(
    attribute: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get player's session attribute (adminGetPlayerSessionAttribute)

    Get player's specific session attribute by user id in a namespace.

    Properties:
        url: /lobby/v1/admin/player/namespaces/{namespace}/users/{userId}/attributes/{attribute}

        method: GET

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        attribute: (attribute) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsGetPlayerSessionAttributeResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetPlayerSessionAttribute.create(
        attribute=attribute,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetPlayerSessionAttribute)
async def admin_get_player_session_attribute_async(
    attribute: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get player's session attribute (adminGetPlayerSessionAttribute)

    Get player's specific session attribute by user id in a namespace.

    Properties:
        url: /lobby/v1/admin/player/namespaces/{namespace}/users/{userId}/attributes/{attribute}

        method: GET

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        attribute: (attribute) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsGetPlayerSessionAttributeResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetPlayerSessionAttribute.create(
        attribute=attribute,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminSetPlayerSessionAttribute)
def admin_set_player_session_attribute(
    body: ModelsSetPlayerSessionAttributeRequest,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin set player's session attribute (adminSetPlayerSessionAttribute)

    Set player's session attribute by user id in a namespace.

    Properties:
        url: /lobby/v1/admin/player/namespaces/{namespace}/users/{userId}/attributes

        method: PUT

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsSetPlayerSessionAttributeRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminSetPlayerSessionAttribute.create(
        body=body,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminSetPlayerSessionAttribute)
async def admin_set_player_session_attribute_async(
    body: ModelsSetPlayerSessionAttributeRequest,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin set player's session attribute (adminSetPlayerSessionAttribute)

    Set player's session attribute by user id in a namespace.

    Properties:
        url: /lobby/v1/admin/player/namespaces/{namespace}/users/{userId}/attributes

        method: PUT

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsSetPlayerSessionAttributeRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminSetPlayerSessionAttribute.create(
        body=body,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicGetPlayerBlockedByPlayersV1)
def public_get_player_blocked_by_players_v1(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get players who blocked this player by user id (publicGetPlayerBlockedByPlayersV1)

    Required valid user authorization


    load get players who blocked this player in a namespace based on user id

    Action Code: 50101

    Properties:
        url: /lobby/v1/public/player/namespaces/{namespace}/users/me/blocked-by

        method: GET

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsGetAllPlayerBlockedByUsersResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetPlayerBlockedByPlayersV1.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGetPlayerBlockedByPlayersV1)
async def public_get_player_blocked_by_players_v1_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get players who blocked this player by user id (publicGetPlayerBlockedByPlayersV1)

    Required valid user authorization


    load get players who blocked this player in a namespace based on user id

    Action Code: 50101

    Properties:
        url: /lobby/v1/public/player/namespaces/{namespace}/users/me/blocked-by

        method: GET

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsGetAllPlayerBlockedByUsersResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetPlayerBlockedByPlayersV1.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicGetPlayerBlockedPlayersV1)
def public_get_player_blocked_players_v1(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get blocked players by user id (publicGetPlayerBlockedPlayersV1)

    Required valid user authorization


    load blocked players in a namespace based on user id

    Action Code: 50101

    Properties:
        url: /lobby/v1/public/player/namespaces/{namespace}/users/me/blocked

        method: GET

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsGetAllPlayerBlockedUsersResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetPlayerBlockedPlayersV1.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGetPlayerBlockedPlayersV1)
async def public_get_player_blocked_players_v1_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get blocked players by user id (publicGetPlayerBlockedPlayersV1)

    Required valid user authorization


    load blocked players in a namespace based on user id

    Action Code: 50101

    Properties:
        url: /lobby/v1/public/player/namespaces/{namespace}/users/me/blocked

        method: GET

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsGetAllPlayerBlockedUsersResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetPlayerBlockedPlayersV1.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicPlayerBlockPlayersV1)
def public_player_block_players_v1(
    body: ModelsBlockPlayerRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """block player by user id (publicPlayerBlockPlayersV1)

    Required valid user authorization


    add blocked players in a namespace based on user id

    Properties:
        url: /lobby/v1/public/player/namespaces/{namespace}/users/me/block

        method: POST

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsBlockPlayerRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        201: Created - (Created)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicPlayerBlockPlayersV1.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicPlayerBlockPlayersV1)
async def public_player_block_players_v1_async(
    body: ModelsBlockPlayerRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """block player by user id (publicPlayerBlockPlayersV1)

    Required valid user authorization


    add blocked players in a namespace based on user id

    Properties:
        url: /lobby/v1/public/player/namespaces/{namespace}/users/me/block

        method: POST

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsBlockPlayerRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        201: Created - (Created)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicPlayerBlockPlayersV1.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicUnblockPlayerV1)
def public_unblock_player_v1(
    body: ModelsUnblockPlayerRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """unblock player by user id (publicUnblockPlayerV1)

    Required valid user authorization

    unblock player in a namespace based on user id

    Properties:
        url: /lobby/v1/public/player/namespaces/{namespace}/users/me/unblock

        method: POST

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUnblockPlayerRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicUnblockPlayerV1.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicUnblockPlayerV1)
async def public_unblock_player_v1_async(
    body: ModelsUnblockPlayerRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """unblock player by user id (publicUnblockPlayerV1)

    Required valid user authorization

    unblock player in a namespace based on user id

    Properties:
        url: /lobby/v1/public/player/namespaces/{namespace}/users/me/unblock

        method: POST

        tags: ["player"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUnblockPlayerRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicUnblockPlayerV1.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Platform Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum


class StatusEnum(StrEnum):
    FAIL = "FAIL"
    SUCCESS = "SUCCESS"


class EntitlementRevocation(Model):
    """Entitlement revocation (EntitlementRevocation)

    Properties:
        custom_revocation: (customRevocation) OPTIONAL Dict[str, Any]

        entitlement_id: (entitlementId) OPTIONAL str

        item_id: (itemId) OPTIONAL str

        item_sku: (itemSku) OPTIONAL str

        quantity: (quantity) OPTIONAL int

        reason: (reason) OPTIONAL str

        revocation_strategy: (revocationStrategy) OPTIONAL str

        skipped: (skipped) OPTIONAL bool

        status: (status) OPTIONAL Union[str, StatusEnum]
    """

    # region fields

    custom_revocation: Dict[str, Any]  # OPTIONAL
    entitlement_id: str  # OPTIONAL
    item_id: str  # OPTIONAL
    item_sku: str  # OPTIONAL
    quantity: int  # OPTIONAL
    reason: str  # OPTIONAL
    revocation_strategy: str  # OPTIONAL
    skipped: bool  # OPTIONAL
    status: Union[str, StatusEnum]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_custom_revocation(self, value: Dict[str, Any]) -> EntitlementRevocation:
        self.custom_revocation = value
        return self

    def with_entitlement_id(self, value: str) -> EntitlementRevocation:
        self.entitlement_id = value
        return self

    def with_item_id(self, value: str) -> EntitlementRevocation:
        self.item_id = value
        return self

    def with_item_sku(self, value: str) -> EntitlementRevocation:
        self.item_sku = value
        return self

    def with_quantity(self, value: int) -> EntitlementRevocation:
        self.quantity = value
        return self

    def with_reason(self, value: str) -> EntitlementRevocation:
        self.reason = value
        return self

    def with_revocation_strategy(self, value: str) -> EntitlementRevocation:
        self.revocation_strategy = value
        return self

    def with_skipped(self, value: bool) -> EntitlementRevocation:
        self.skipped = value
        return self

    def with_status(self, value: Union[str, StatusEnum]) -> EntitlementRevocation:
        self.status = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "custom_revocation"):
            result["customRevocation"] = {
                str(k0): v0 for k0, v0 in self.custom_revocation.items()
            }
        elif include_empty:
            result["customRevocation"] = {}
        if hasattr(self, "entitlement_id"):
            result["entitlementId"] = str(self.entitlement_id)
        elif include_empty:
            result["entitlementId"] = ""
        if hasattr(self, "item_id"):
            result["itemId"] = str(self.item_id)
        elif include_empty:
            result["itemId"] = ""
        if hasattr(self, "item_sku"):
            result["itemSku"] = str(self.item_sku)
        elif include_empty:
            result["itemSku"] = ""
        if hasattr(self, "quantity"):
            result["quantity"] = int(self.quantity)
        elif include_empty:
            result["quantity"] = 0
        if hasattr(self, "reason"):
            result["reason"] = str(self.reason)
        elif include_empty:
            result["reason"] = ""
        if hasattr(self, "revocation_strategy"):
            result["revocationStrategy"] = str(self.revocation_strategy)
        elif include_empty:
            result["revocationStrategy"] = ""
        if hasattr(self, "skipped"):
            result["skipped"] = bool(self.skipped)
        elif include_empty:
            result["skipped"] = False
        if hasattr(self, "status"):
            result["status"] = str(self.status)
        elif include_empty:
            result["status"] = Union[str, StatusEnum]()
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        custom_revocation: Optional[Dict[str, Any]] = None,
        entitlement_id: Optional[str] = None,
        item_id: Optional[str] = None,
        item_sku: Optional[str] = None,
        quantity: Optional[int] = None,
        reason: Optional[str] = None,
        revocation_strategy: Optional[str] = None,
        skipped: Optional[bool] = None,
        status: Optional[Union[str, StatusEnum]] = None,
        **kwargs,
    ) -> EntitlementRevocation:
        instance = cls()
        if custom_revocation is not None:
            instance.custom_revocation = custom_revocation
        if entitlement_id is not None:
            instance.entitlement_id = entitlement_id
        if item_id is not None:
            instance.item_id = item_id
        if item_sku is not None:
            instance.item_sku = item_sku
        if quantity is not None:
            instance.quantity = quantity
        if reason is not None:
            instance.reason = reason
        if revocation_strategy is not None:
            instance.revocation_strategy = revocation_strategy
        if skipped is not None:
            instance.skipped = skipped
        if status is not None:
            instance.status = status
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> EntitlementRevocation:
        instance = cls()
        if not dict_:
            return instance
        if "customRevocation" in dict_ and dict_["customRevocation"] is not None:
            instance.custom_revocation = {
                str(k0): v0 for k0, v0 in dict_["customRevocation"].items()
            }
        elif include_empty:
            instance.custom_revocation = {}
        if "entitlementId" in dict_ and dict_["entitlementId"] is not None:
            instance.entitlement_id = str(dict_["entitlementId"])
        elif include_empty:
            instance.entitlement_id = ""
        if "itemId" in dict_ and dict_["itemId"] is not None:
            instance.item_id = str(dict_["itemId"])
        elif include_empty:
            instance.item_id = ""
        if "itemSku" in dict_ and dict_["itemSku"] is not None:
            instance.item_sku = str(dict_["itemSku"])
        elif include_empty:
            instance.item_sku = ""
        if "quantity" in dict_ and dict_["quantity"] is not None:
            instance.quantity = int(dict_["quantity"])
        elif include_empty:
            instance.quantity = 0
        if "reason" in dict_ and dict_["reason"] is not None:
            instance.reason = str(dict_["reason"])
        elif include_empty:
            instance.reason = ""
        if "revocationStrategy" in dict_ and dict_["revocationStrategy"] is not None:
            instance.revocation_strategy = str(dict_["revocationStrategy"])
        elif include_empty:
            instance.revocation_strategy = ""
        if "skipped" in dict_ and dict_["skipped"] is not None:
            instance.skipped = bool(dict_["skipped"])
        elif include_empty:
            instance.skipped = False
        if "status" in dict_ and dict_["status"] is not None:
            instance.status = str(dict_["status"])
        elif include_empty:
            instance.status = Union[str, StatusEnum]()
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, EntitlementRevocation]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[EntitlementRevocation]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        EntitlementRevocation,
        List[EntitlementRevocation],
        Dict[Any, EntitlementRevocation],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "customRevocation": "custom_revocation",
            "entitlementId": "entitlement_id",
            "itemId": "item_id",
            "itemSku": "item_sku",
            "quantity": "quantity",
            "reason": "reason",
            "revocationStrategy": "revocation_strategy",
            "skipped": "skipped",
            "status": "status",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "customRevocation": False,
            "entitlementId": False,
            "itemId": False,
            "itemSku": False,
            "quantity": False,
            "reason": False,
            "revocationStrategy": False,
            "skipped": False,
            "status": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "status": ["FAIL", "SUCCESS"],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import OrderSyncResult

from ..operations.order_dedicated import SyncOrders


@same_doc_as(SyncOrders)
def sync_orders(
    end: str,
    start: str,
    next_evaluated_key: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Sync orders (syncOrders)

    [Not Supported Yet In Starter] Sync orders. If response contains nextEvaluatedKey, please use it as query param in the next call to fetch the next batch, a batch has 1000 elements or less.
    Other detail info:

      * Returns : sync orders

    Properties:
        url: /platform/admin/orders

        method: GET

        tags: ["Order(Dedicated)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        next_evaluated_key: (nextEvaluatedKey) OPTIONAL str in query

        end: (end) REQUIRED str in query

        start: (start) REQUIRED str in query

    Responses:
        200: OK - OrderSyncResult (successful operation)
    """
    request = SyncOrders.create(
        end=end,
        start=start,
        next_evaluated_key=next_evaluated_key,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(SyncOrders)
async def sync_orders_async(
    end: str,
    start: str,
    next_evaluated_key: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Sync orders (syncOrders)

    [Not Supported Yet In Starter] Sync orders. If response contains nextEvaluatedKey, please use it as query param in the next call to fetch the next batch, a batch has 1000 elements or less.
    Other detail info:

      * Returns : sync orders

    Properties:
        url: /platform/admin/orders

        method: GET

        tags: ["Order(Dedicated)"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        next_evaluated_key: (nextEvaluatedKey) OPTIONAL str in query

        end: (end) REQUIRED str in query

        start: (start) REQUIRED str in query

    Responses:
        200: OK - OrderSyncResult (successful operation)
    """
    request = SyncOrders.create(
        end=end,
        start=start,
        next_evaluated_key=next_evaluated_key,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelsListAllQueueResponse
from ..models import ModelsListNodesIPAddress
from ..models import ModelsListQueueResponse
from ..models import ModelsQueue
from ..models import ResponseError

from ..operations.artifact_upload_process_queue import DeleteActiveQueue
from ..operations.artifact_upload_process_queue import DeleteNodeByID
from ..operations.artifact_upload_process_queue import DeleteQueue
from ..operations.artifact_upload_process_queue import GetActiveQueue
from ..operations.artifact_upload_process_queue import ListAllActiveQueue
from ..operations.artifact_upload_process_queue import ListAllQueue
from ..operations.artifact_upload_process_queue import ListNodesIPAddress
from ..operations.artifact_upload_process_queue import ListQueue
from ..operations.artifact_upload_process_queue import ReportFailedUpload
from ..operations.artifact_upload_process_queue import SetActiveQueue


@same_doc_as(DeleteActiveQueue)
def delete_active_queue(
    node_ip: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Delete active queue process on a node (deleteActiveQueue)

    ```
    Required permission: ADMIN:DSAM:ARTIFACT:QUEUE [DELETE]

    This endpoint is used to delete active queue process on a node
    ```

    Required Permission(s):
        - ADMIN:DSAM:ARTIFACT:QUEUE [DELETE]

    Properties:
        url: /dsartifact/artifacts/queues/active

        method: DELETE

        tags: ["Artifact Upload Process Queue"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        node_ip: (nodeIP) REQUIRED str in query

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    request = DeleteActiveQueue.create(
        node_ip=node_ip,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteActiveQueue)
async def delete_active_queue_async(
    node_ip: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Delete active queue process on a node (deleteActiveQueue)

    ```
    Required permission: ADMIN:DSAM:ARTIFACT:QUEUE [DELETE]

    This endpoint is used to delete active queue process on a node
    ```

    Required Permission(s):
        - ADMIN:DSAM:ARTIFACT:QUEUE [DELETE]

    Properties:
        url: /dsartifact/artifacts/queues/active

        method: DELETE

        tags: ["Artifact Upload Process Queue"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        node_ip: (nodeIP) REQUIRED str in query

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    request = DeleteActiveQueue.create(
        node_ip=node_ip,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteNodeByID)
def delete_node_by_id(
    node_ip: str,
    pod_name: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete a node that previously held artifact queue by IP address (deleteNodeByID)

    Required permission: ADMIN:DSAM:ARTIFACT:NODES [DELETE]

    Required scope: social

    This endpoint will delete a node by IP

    Required Permission(s):
        - ADMIN:DSAM:ARTIFACT:NODES [DELETE]

    Required Scope(s):
        - social

    Properties:
        url: /dsartifact/artifacts/nodes/ipaddresses

        method: DELETE

        tags: ["Artifact Upload Process Queue"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        node_ip: (nodeIP) REQUIRED str in query

        pod_name: (podName) REQUIRED str in query

    Responses:
        204: No Content - (delete queue success.)

        400: Bad Request - ResponseError (Bad Request)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    request = DeleteNodeByID.create(
        node_ip=node_ip,
        pod_name=pod_name,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteNodeByID)
async def delete_node_by_id_async(
    node_ip: str,
    pod_name: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete a node that previously held artifact queue by IP address (deleteNodeByID)

    Required permission: ADMIN:DSAM:ARTIFACT:NODES [DELETE]

    Required scope: social

    This endpoint will delete a node by IP

    Required Permission(s):
        - ADMIN:DSAM:ARTIFACT:NODES [DELETE]

    Required Scope(s):
        - social

    Properties:
        url: /dsartifact/artifacts/nodes/ipaddresses

        method: DELETE

        tags: ["Artifact Upload Process Queue"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        node_ip: (nodeIP) REQUIRED str in query

        pod_name: (podName) REQUIRED str in query

    Responses:
        204: No Content - (delete queue success.)

        400: Bad Request - ResponseError (Bad Request)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    request = DeleteNodeByID.create(
        node_ip=node_ip,
        pod_name=pod_name,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteQueue)
def delete_queue(
    node_ip: str,
    pod_name: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete a queue entry (deleteQueue)

    Required permission: ADMIN:NAMESPACE:{namespace}:DSAM:ARTIFACT:QUEUE [DELETE]

    Required scope: social

    This endpoint will delete a queue entry

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DSAM:ARTIFACT:QUEUE [DELETE]

    Required Scope(s):
        - social

    Properties:
        url: /dsartifact/namespaces/{namespace}/artifacts/queues

        method: DELETE

        tags: ["Artifact Upload Process Queue"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        node_ip: (nodeIP) REQUIRED str in query

        pod_name: (podName) REQUIRED str in query

    Responses:
        204: No Content - (delete queue success.)

        400: Bad Request - ResponseError (Bad Request)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteQueue.create(
        node_ip=node_ip,
        pod_name=pod_name,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteQueue)
async def delete_queue_async(
    node_ip: str,
    pod_name: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete a queue entry (deleteQueue)

    Required permission: ADMIN:NAMESPACE:{namespace}:DSAM:ARTIFACT:QUEUE [DELETE]

    Required scope: social

    This endpoint will delete a queue entry

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DSAM:ARTIFACT:QUEUE [DELETE]

    Required Scope(s):
        - social

    Properties:
        url: /dsartifact/namespaces/{namespace}/artifacts/queues

        method: DELETE

        tags: ["Artifact Upload Process Queue"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        node_ip: (nodeIP) REQUIRED str in query

        pod_name: (podName) REQUIRED str in query

    Responses:
        204: No Content - (delete queue success.)

        400: Bad Request - ResponseError (Bad Request)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteQueue.create(
        node_ip=node_ip,
        pod_name=pod_name,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetActiveQueue)
def get_active_queue(
    node_ip: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Get active queue process on a node (getActiveQueue)

    ```
    Required permission: ADMIN:DSAM:ARTIFACT:QUEUE [READ]

    This endpoint is used to get an active queue process on a node
    ```

    Required Permission(s):
        - ADMIN:DSAM:ARTIFACT:QUEUE [READ]

    Properties:
        url: /dsartifact/artifacts/queues/active

        method: GET

        tags: ["Artifact Upload Process Queue"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        node_ip: (nodeIP) REQUIRED str in query

    Responses:
        200: OK - ModelsQueue (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    request = GetActiveQueue.create(
        node_ip=node_ip,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetActiveQueue)
async def get_active_queue_async(
    node_ip: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Get active queue process on a node (getActiveQueue)

    ```
    Required permission: ADMIN:DSAM:ARTIFACT:QUEUE [READ]

    This endpoint is used to get an active queue process on a node
    ```

    Required Permission(s):
        - ADMIN:DSAM:ARTIFACT:QUEUE [READ]

    Properties:
        url: /dsartifact/artifacts/queues/active

        method: GET

        tags: ["Artifact Upload Process Queue"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        node_ip: (nodeIP) REQUIRED str in query

    Responses:
        200: OK - ModelsQueue (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    request = GetActiveQueue.create(
        node_ip=node_ip,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(ListAllActiveQueue)
def list_all_active_queue(
    limit: Optional[int] = None,
    next_: Optional[str] = None,
    node_ip: Optional[str] = None,
    pod_name: Optional[str] = None,
    previous: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get all currently uploading artifact queue (listAllActiveQueue)

    Required permission: ADMIN:NAMESPACE:{namespace}:DSAM:ARTIFACT:QUEUE [READ]

    Required scope: social

    This endpoint will list all DSes which artifact is currently in uploading process.

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DSAM:ARTIFACT:QUEUE [READ]

    Required Scope(s):
        - social

    Properties:
        url: /dsartifact/namespaces/{namespace}/artifacts/queues/active/all

        method: GET

        tags: ["Artifact Upload Process Queue"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        next_: (next) OPTIONAL str in query

        node_ip: (nodeIP) OPTIONAL str in query

        pod_name: (podName) OPTIONAL str in query

        previous: (previous) OPTIONAL str in query

    Responses:
        200: OK - ModelsListAllQueueResponse (get all active queue success.)

        400: Bad Request - ResponseError (Bad Request)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = ListAllActiveQueue.create(
        limit=limit,
        next_=next_,
        node_ip=node_ip,
        pod_name=pod_name,
        previous=previous,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(ListAllActiveQueue)
async def list_all_active_queue_async(
    limit: Optional[int] = None,
    next_: Optional[str] = None,
    node_ip: Optional[str] = None,
    pod_name: Optional[str] = None,
    previous: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get all currently uploading artifact queue (listAllActiveQueue)

    Required permission: ADMIN:NAMESPACE:{namespace}:DSAM:ARTIFACT:QUEUE [READ]

    Required scope: social

    This endpoint will list all DSes which artifact is currently in uploading process.

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DSAM:ARTIFACT:QUEUE [READ]

    Required Scope(s):
        - social

    Properties:
        url: /dsartifact/namespaces/{namespace}/artifacts/queues/active/all

        method: GET

        tags: ["Artifact Upload Process Queue"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        next_: (next) OPTIONAL str in query

        node_ip: (nodeIP) OPTIONAL str in query

        pod_name: (podName) OPTIONAL str in query

        previous: (previous) OPTIONAL str in query

    Responses:
        200: OK - ModelsListAllQueueResponse (get all active queue success.)

        400: Bad Request - ResponseError (Bad Request)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = ListAllActiveQueue.create(
        limit=limit,
        next_=next_,
        node_ip=node_ip,
        pod_name=pod_name,
        previous=previous,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(ListAllQueue)
def list_all_queue(
    exclude_uploading: Optional[bool] = None,
    limit: Optional[int] = None,
    next_: Optional[str] = None,
    node_ip: Optional[str] = None,
    order: Optional[str] = None,
    pod_name: Optional[str] = None,
    previous: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get all artifact upload process queues (listAllQueue)

    Required permission: ADMIN:NAMESPACE:{namespace}:DSAM:ARTIFACT:QUEUE [READ]

    Required scope: social

    This endpoint will list all DSes which has artifact in upload queue.

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DSAM:ARTIFACT:QUEUE [READ]

    Required Scope(s):
        - social

    Properties:
        url: /dsartifact/namespaces/{namespace}/artifacts/queues/all

        method: GET

        tags: ["Artifact Upload Process Queue"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        exclude_uploading: (exclude_uploading) OPTIONAL bool in query

        limit: (limit) OPTIONAL int in query

        next_: (next) OPTIONAL str in query

        node_ip: (nodeIP) OPTIONAL str in query

        order: (order) OPTIONAL str in query

        pod_name: (pod_name) OPTIONAL str in query

        previous: (previous) OPTIONAL str in query

    Responses:
        200: OK - ModelsListAllQueueResponse (get all queue success.)

        400: Bad Request - ResponseError (Bad Request)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = ListAllQueue.create(
        exclude_uploading=exclude_uploading,
        limit=limit,
        next_=next_,
        node_ip=node_ip,
        order=order,
        pod_name=pod_name,
        previous=previous,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(ListAllQueue)
async def list_all_queue_async(
    exclude_uploading: Optional[bool] = None,
    limit: Optional[int] = None,
    next_: Optional[str] = None,
    node_ip: Optional[str] = None,
    order: Optional[str] = None,
    pod_name: Optional[str] = None,
    previous: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get all artifact upload process queues (listAllQueue)

    Required permission: ADMIN:NAMESPACE:{namespace}:DSAM:ARTIFACT:QUEUE [READ]

    Required scope: social

    This endpoint will list all DSes which has artifact in upload queue.

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DSAM:ARTIFACT:QUEUE [READ]

    Required Scope(s):
        - social

    Properties:
        url: /dsartifact/namespaces/{namespace}/artifacts/queues/all

        method: GET

        tags: ["Artifact Upload Process Queue"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        exclude_uploading: (exclude_uploading) OPTIONAL bool in query

        limit: (limit) OPTIONAL int in query

        next_: (next) OPTIONAL str in query

        node_ip: (nodeIP) OPTIONAL str in query

        order: (order) OPTIONAL str in query

        pod_name: (pod_name) OPTIONAL str in query

        previous: (previous) OPTIONAL str in query

    Responses:
        200: OK - ModelsListAllQueueResponse (get all queue success.)

        400: Bad Request - ResponseError (Bad Request)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = ListAllQueue.create(
        exclude_uploading=exclude_uploading,
        limit=limit,
        next_=next_,
        node_ip=node_ip,
        order=order,
        pod_name=pod_name,
        previous=previous,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(ListNodesIPAddress)
def list_nodes_ip_address(
    limit: Optional[int] = None,
    next_: Optional[str] = None,
    node_ip: Optional[str] = None,
    previous: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get IP Address of all nodes that all artifact in queue resides. This IP Address is the IP Address of nomad client (listNodesIPAddress)

    Required permission: ADMIN:DSAM:ARTIFACT:NODES [READ]

    Required scope: social

    This endpoint will list IP Address of all artifact queue

    Required Permission(s):
        - ADMIN:DSAM:ARTIFACT:NODES [READ]

    Required Scope(s):
        - social

    Properties:
        url: /dsartifact/artifacts/nodes/ipaddresses

        method: GET

        tags: ["Artifact Upload Process Queue"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        limit: (limit) OPTIONAL int in query

        next_: (next) OPTIONAL str in query

        node_ip: (nodeIP) OPTIONAL str in query

        previous: (previous) OPTIONAL str in query

    Responses:
        200: OK - ModelsListNodesIPAddress (get all active queue success.)

        400: Bad Request - ResponseError (Bad Request)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    request = ListNodesIPAddress.create(
        limit=limit,
        next_=next_,
        node_ip=node_ip,
        previous=previous,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(ListNodesIPAddress)
async def list_nodes_ip_address_async(
    limit: Optional[int] = None,
    next_: Optional[str] = None,
    node_ip: Optional[str] = None,
    previous: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get IP Address of all nodes that all artifact in queue resides. This IP Address is the IP Address of nomad client (listNodesIPAddress)

    Required permission: ADMIN:DSAM:ARTIFACT:NODES [READ]

    Required scope: social

    This endpoint will list IP Address of all artifact queue

    Required Permission(s):
        - ADMIN:DSAM:ARTIFACT:NODES [READ]

    Required Scope(s):
        - social

    Properties:
        url: /dsartifact/artifacts/nodes/ipaddresses

        method: GET

        tags: ["Artifact Upload Process Queue"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        limit: (limit) OPTIONAL int in query

        next_: (next) OPTIONAL str in query

        node_ip: (nodeIP) OPTIONAL str in query

        previous: (previous) OPTIONAL str in query

    Responses:
        200: OK - ModelsListNodesIPAddress (get all active queue success.)

        400: Bad Request - ResponseError (Bad Request)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    request = ListNodesIPAddress.create(
        limit=limit,
        next_=next_,
        node_ip=node_ip,
        previous=previous,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(ListQueue)
def list_queue(
    node_ip: str,
    limit: Optional[int] = None,
    next_: Optional[str] = None,
    previous: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get list of queues on a node (listQueue)

    ```
    Required permission: ADMIN:DSAM:ARTIFACT:QUEUE [READ]

    This endpoint is used to get the list of queues on a node
    ```

    Required Permission(s):
        - ADMIN:DSAM:ARTIFACT:QUEUE [READ]

    Properties:
        url: /dsartifact/artifacts/queues

        method: GET

        tags: ["Artifact Upload Process Queue"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        limit: (limit) OPTIONAL int in query

        next_: (next) OPTIONAL str in query

        previous: (previous) OPTIONAL str in query

        node_ip: (nodeIP) REQUIRED str in query

    Responses:
        200: OK - ModelsListQueueResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    request = ListQueue.create(
        node_ip=node_ip,
        limit=limit,
        next_=next_,
        previous=previous,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(ListQueue)
async def list_queue_async(
    node_ip: str,
    limit: Optional[int] = None,
    next_: Optional[str] = None,
    previous: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get list of queues on a node (listQueue)

    ```
    Required permission: ADMIN:DSAM:ARTIFACT:QUEUE [READ]

    This endpoint is used to get the list of queues on a node
    ```

    Required Permission(s):
        - ADMIN:DSAM:ARTIFACT:QUEUE [READ]

    Properties:
        url: /dsartifact/artifacts/queues

        method: GET

        tags: ["Artifact Upload Process Queue"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        limit: (limit) OPTIONAL int in query

        next_: (next) OPTIONAL str in query

        previous: (previous) OPTIONAL str in query

        node_ip: (nodeIP) REQUIRED str in query

    Responses:
        200: OK - ModelsListQueueResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    request = ListQueue.create(
        node_ip=node_ip,
        limit=limit,
        next_=next_,
        previous=previous,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(ReportFailedUpload)
def report_failed_upload(
    node_ip: str,
    pod_name: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Report failed artifact upload (reportFailedUpload)

    ```
    Required permission: ADMIN:DSAM:ARTIFACT:QUEUE [UPDATE]

    This endpoint is used to report a failed artifact upload
    ```

    Required Permission(s):
        - ADMIN:DSAM:ARTIFACT:QUEUE [UPDATE]

    Properties:
        url: /dsartifact/artifacts/queues/failed

        method: PUT

        tags: ["Artifact Upload Process Queue"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        node_ip: (nodeIP) REQUIRED str in query

        pod_name: (podName) REQUIRED str in query

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    request = ReportFailedUpload.create(
        node_ip=node_ip,
        pod_name=pod_name,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(ReportFailedUpload)
async def report_failed_upload_async(
    node_ip: str,
    pod_name: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Report failed artifact upload (reportFailedUpload)

    ```
    Required permission: ADMIN:DSAM:ARTIFACT:QUEUE [UPDATE]

    This endpoint is used to report a failed artifact upload
    ```

    Required Permission(s):
        - ADMIN:DSAM:ARTIFACT:QUEUE [UPDATE]

    Properties:
        url: /dsartifact/artifacts/queues/failed

        method: PUT

        tags: ["Artifact Upload Process Queue"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        node_ip: (nodeIP) REQUIRED str in query

        pod_name: (podName) REQUIRED str in query

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    request = ReportFailedUpload.create(
        node_ip=node_ip,
        pod_name=pod_name,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(SetActiveQueue)
def set_active_queue(
    node_ip: str,
    pod_name: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Set a queue as active queue (setActiveQueue)

    ```
    Required permission: ADMIN:DSAM:ARTIFACT:QUEUE [UPDATE]

    This endpoint is used to set a queue entry as the current active queue
    for artifact uploading process on a node
    ```

    Required Permission(s):
        - ADMIN:DSAM:ARTIFACT:QUEUE [UPDATE]

    Properties:
        url: /dsartifact/artifacts/queues/active

        method: PUT

        tags: ["Artifact Upload Process Queue"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        node_ip: (nodeIP) REQUIRED str in query

        pod_name: (podName) REQUIRED str in query

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    request = SetActiveQueue.create(
        node_ip=node_ip,
        pod_name=pod_name,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(SetActiveQueue)
async def set_active_queue_async(
    node_ip: str,
    pod_name: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Set a queue as active queue (setActiveQueue)

    ```
    Required permission: ADMIN:DSAM:ARTIFACT:QUEUE [UPDATE]

    This endpoint is used to set a queue entry as the current active queue
    for artifact uploading process on a node
    ```

    Required Permission(s):
        - ADMIN:DSAM:ARTIFACT:QUEUE [UPDATE]

    Properties:
        url: /dsartifact/artifacts/queues/active

        method: PUT

        tags: ["Artifact Upload Process Queue"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        node_ip: (nodeIP) REQUIRED str in query

        pod_name: (podName) REQUIRED str in query

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    request = SetActiveQueue.create(
        node_ip=node_ip,
        pod_name=pod_name,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Ds Artifact Manager."""

__version__ = "1.11.4"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

# all_terminated_servers
from .wrappers import list_terminated_servers
from .wrappers import list_terminated_servers_async

# artifact_upload_process_queue
from .wrappers import delete_active_queue
from .wrappers import delete_active_queue_async
from .wrappers import delete_node_by_id
from .wrappers import delete_node_by_id_async
from .wrappers import delete_queue
from .wrappers import delete_queue_async
from .wrappers import get_active_queue
from .wrappers import get_active_queue_async
from .wrappers import list_all_active_queue
from .wrappers import list_all_active_queue_async
from .wrappers import list_all_queue
from .wrappers import list_all_queue_async
from .wrappers import list_nodes_ip_address
from .wrappers import list_nodes_ip_address_async
from .wrappers import list_queue
from .wrappers import list_queue_async
from .wrappers import report_failed_upload
from .wrappers import report_failed_upload_async
from .wrappers import set_active_queue
from .wrappers import set_active_queue_async

# download_server_artifact
from .wrappers import check_server_artifact
from .wrappers import check_server_artifact_async
from .wrappers import download_server_artifacts
from .wrappers import download_server_artifacts_async

# operations
from .wrappers import public_get_messages
from .wrappers import public_get_messages_async

# terminated_servers
from .wrappers import list_terminated_servers_with_namespace
from .wrappers import list_terminated_servers_with_namespace_async



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ErrorEntity
from ..models import RevocationConfigInfo
from ..models import RevocationConfigUpdate
from ..models import RevocationHistoryPagingSlicedResult
from ..models import RevocationRequest
from ..models import RevocationResult

from ..operations.revocation import DeleteRevocationConfig
from ..operations.revocation import DoRevocation
from ..operations.revocation import GetRevocationConfig
from ..operations.revocation import QueryRevocationHistories
from ..operations.revocation import (
    QueryRevocationHistoriesSourceEnum,
    QueryRevocationHistoriesStatusEnum,
)
from ..operations.revocation import UpdateRevocationConfig
from ..models import RevocationRequestSourceEnum
from ..models import RevocationResultStatusEnum


@same_doc_as(DeleteRevocationConfig)
def delete_revocation_config(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete revocation config (deleteRevocationConfig)

    Delete revocation config.

    Properties:
        url: /platform/admin/namespaces/{namespace}/revocation/config

        method: DELETE

        tags: ["Revocation"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (Delete successfully)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteRevocationConfig.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteRevocationConfig)
async def delete_revocation_config_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete revocation config (deleteRevocationConfig)

    Delete revocation config.

    Properties:
        url: /platform/admin/namespaces/{namespace}/revocation/config

        method: DELETE

        tags: ["Revocation"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (Delete successfully)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteRevocationConfig.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DoRevocation)
def do_revocation(
    user_id: str,
    body: Optional[RevocationRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Do revocation. (doRevocation)

    Do revocation.
    Other detail info:

      * Returns : revocation results

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/revocation

        method: PUT

        tags: ["Revocation"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL RevocationRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - RevocationResult (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DoRevocation.create(
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DoRevocation)
async def do_revocation_async(
    user_id: str,
    body: Optional[RevocationRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Do revocation. (doRevocation)

    Do revocation.
    Other detail info:

      * Returns : revocation results

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/revocation

        method: PUT

        tags: ["Revocation"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL RevocationRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - RevocationResult (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DoRevocation.create(
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetRevocationConfig)
def get_revocation_config(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get revocation configuration (getRevocationConfig)

    Get revocation configuration.
    Other detail info:

      * Returns : Revocation config

    Properties:
        url: /platform/admin/namespaces/{namespace}/revocation/config

        method: GET

        tags: ["Revocation"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - RevocationConfigInfo (successful operation)

        404: Not Found - ErrorEntity (33243: Payment callback config for [{namespace}] does not exist)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetRevocationConfig.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetRevocationConfig)
async def get_revocation_config_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get revocation configuration (getRevocationConfig)

    Get revocation configuration.
    Other detail info:

      * Returns : Revocation config

    Properties:
        url: /platform/admin/namespaces/{namespace}/revocation/config

        method: GET

        tags: ["Revocation"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - RevocationConfigInfo (successful operation)

        404: Not Found - ErrorEntity (33243: Payment callback config for [{namespace}] does not exist)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetRevocationConfig.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryRevocationHistories)
def query_revocation_histories(
    end_time: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    source: Optional[Union[str, QueryRevocationHistoriesSourceEnum]] = None,
    start_time: Optional[str] = None,
    status: Optional[Union[str, QueryRevocationHistoriesStatusEnum]] = None,
    transaction_id: Optional[str] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query revocation histories (queryRevocationHistories)

    Query revocation histories in a namespace.
    Other detail info:

      * Returns : query revocation history

    Properties:
        url: /platform/admin/namespaces/{namespace}/revocation/history

        method: GET

        tags: ["Revocation"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end_time: (endTime) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        source: (source) OPTIONAL Union[str, SourceEnum] in query

        start_time: (startTime) OPTIONAL str in query

        status: (status) OPTIONAL Union[str, StatusEnum] in query

        transaction_id: (transactionId) OPTIONAL str in query

        user_id: (userId) OPTIONAL str in query

    Responses:
        200: OK - RevocationHistoryPagingSlicedResult (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryRevocationHistories.create(
        end_time=end_time,
        limit=limit,
        offset=offset,
        source=source,
        start_time=start_time,
        status=status,
        transaction_id=transaction_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryRevocationHistories)
async def query_revocation_histories_async(
    end_time: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    source: Optional[Union[str, QueryRevocationHistoriesSourceEnum]] = None,
    start_time: Optional[str] = None,
    status: Optional[Union[str, QueryRevocationHistoriesStatusEnum]] = None,
    transaction_id: Optional[str] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query revocation histories (queryRevocationHistories)

    Query revocation histories in a namespace.
    Other detail info:

      * Returns : query revocation history

    Properties:
        url: /platform/admin/namespaces/{namespace}/revocation/history

        method: GET

        tags: ["Revocation"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end_time: (endTime) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        source: (source) OPTIONAL Union[str, SourceEnum] in query

        start_time: (startTime) OPTIONAL str in query

        status: (status) OPTIONAL Union[str, StatusEnum] in query

        transaction_id: (transactionId) OPTIONAL str in query

        user_id: (userId) OPTIONAL str in query

    Responses:
        200: OK - RevocationHistoryPagingSlicedResult (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryRevocationHistories.create(
        end_time=end_time,
        limit=limit,
        offset=offset,
        source=source,
        start_time=start_time,
        status=status,
        transaction_id=transaction_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateRevocationConfig)
def update_revocation_config(
    body: Optional[RevocationConfigUpdate] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update revocation configuration (updateRevocationConfig)

    Update revocation configuration.
    Other detail info:

      * Returns : Revocation config

    Properties:
        url: /platform/admin/namespaces/{namespace}/revocation/config

        method: PUT

        tags: ["Revocation"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL RevocationConfigUpdate in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - RevocationConfigInfo (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateRevocationConfig.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateRevocationConfig)
async def update_revocation_config_async(
    body: Optional[RevocationConfigUpdate] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update revocation configuration (updateRevocationConfig)

    Update revocation configuration.
    Other detail info:

      * Returns : Revocation config

    Properties:
        url: /platform/admin/namespaces/{namespace}/revocation/config

        method: PUT

        tags: ["Revocation"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL RevocationConfigUpdate in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - RevocationConfigInfo (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateRevocationConfig.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelsArtifactFileStatus
from ..models import ResponseError

from ..operations.download_server_artifact import CheckServerArtifact
from ..operations.download_server_artifact import DownloadServerArtifacts


@same_doc_as(CheckServerArtifact)
def check_server_artifact(
    pod_name: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Check dedicated server artifacts files existence (checkServerArtifact)

    Required permission: ADMIN:NAMESPACE:{namespace}:DSAM:ARTIFACT [READ]

    Required scope: social

    This endpoint will check artifact file existence before download file.

    This endpoint will return the artifact status.

    The possible status is : 'Empty', 'In Queue', 'Uploading', 'Ready', 'Failed'

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DSAM:ARTIFACT [READ]

    Required Scope(s):
        - social

    Properties:
        url: /dsartifact/namespaces/{namespace}/servers/{podName}/artifacts/exists

        method: GET

        tags: ["Download Server Artifact"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        pod_name: (podName) REQUIRED str in path

    Responses:
        200: OK - ModelsArtifactFileStatus (artifact exists.)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = CheckServerArtifact.create(
        pod_name=pod_name,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(CheckServerArtifact)
async def check_server_artifact_async(
    pod_name: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Check dedicated server artifacts files existence (checkServerArtifact)

    Required permission: ADMIN:NAMESPACE:{namespace}:DSAM:ARTIFACT [READ]

    Required scope: social

    This endpoint will check artifact file existence before download file.

    This endpoint will return the artifact status.

    The possible status is : 'Empty', 'In Queue', 'Uploading', 'Ready', 'Failed'

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DSAM:ARTIFACT [READ]

    Required Scope(s):
        - social

    Properties:
        url: /dsartifact/namespaces/{namespace}/servers/{podName}/artifacts/exists

        method: GET

        tags: ["Download Server Artifact"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        pod_name: (podName) REQUIRED str in path

    Responses:
        200: OK - ModelsArtifactFileStatus (artifact exists.)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = CheckServerArtifact.create(
        pod_name=pod_name,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DownloadServerArtifacts)
def download_server_artifacts(
    pod_name: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Download dedicated server artifact files (downloadServerArtifacts)

    Required permission: ADMIN:NAMESPACE:{namespace}:DSAM:ARTIFACT [READ]

    Required scope: social

    This endpoint will download dedicated server's Artifact file (.zip).

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DSAM:ARTIFACT [READ]

    Required Scope(s):
        - social

    Properties:
        url: /dsartifact/namespaces/{namespace}/servers/{podName}/artifacts/download

        method: GET

        tags: ["Download Server Artifact"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        pod_name: (podName) REQUIRED str in path

    Responses:
        200: OK - (server artifact downloaded.)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DownloadServerArtifacts.create(
        pod_name=pod_name,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DownloadServerArtifacts)
async def download_server_artifacts_async(
    pod_name: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Download dedicated server artifact files (downloadServerArtifacts)

    Required permission: ADMIN:NAMESPACE:{namespace}:DSAM:ARTIFACT [READ]

    Required scope: social

    This endpoint will download dedicated server's Artifact file (.zip).

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DSAM:ARTIFACT [READ]

    Required Scope(s):
        - social

    Properties:
        url: /dsartifact/namespaces/{namespace}/servers/{podName}/artifacts/download

        method: GET

        tags: ["Download Server Artifact"]

        consumes: ["application/json"]

        produces: ["application/json", "text/x-log"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        pod_name: (podName) REQUIRED str in path

    Responses:
        200: OK - (server artifact downloaded.)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DownloadServerArtifacts.create(
        pod_name=pod_name,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Platform Service."""

__version__ = "4.52.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .create_currency import CreateCurrency
from .delete_currency import DeleteCurrency
from .get_currency_config import GetCurrencyConfig
from .get_currency_summary import GetCurrencySummary
from .list_currencies import ListCurrencies
from .list_currencies import CurrencyTypeEnum as ListCurrenciesCurrencyTypeEnum
from .public_list_currencies import PublicListCurrencies
from .public_list_currencies import (
    CurrencyTypeEnum as PublicListCurrenciesCurrencyTypeEnum,
)
from .update_currency import UpdateCurrency



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import DtoUserPlatformAccountClosureHistoriesResponse
from ..models import ResponseError

from ..operations.platform_account_closure_history import (
    AdminGetUserPlatformAccountClosureHistories,
)


@same_doc_as(AdminGetUserPlatformAccountClosureHistories)
def admin_get_user_platform_account_closure_histories(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    platform: Optional[str] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get User's Platform Account Closure Histories (AdminGetUserPlatformAccountClosureHistories)

    Get user's platform account closure histories.
    ------
    Supported platforms:
    * psn

    Scope: account

    Required Scope(s):
        - account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/users/platforms/closure/histories

        method: GET

        tags: ["Platform Account Closure History"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        platform: (platform) OPTIONAL str in query

        user_id: (userId) OPTIONAL str in query

    Responses:
        200: OK - DtoUserPlatformAccountClosureHistoriesResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetUserPlatformAccountClosureHistories.create(
        limit=limit,
        offset=offset,
        platform=platform,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetUserPlatformAccountClosureHistories)
async def admin_get_user_platform_account_closure_histories_async(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    platform: Optional[str] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get User's Platform Account Closure Histories (AdminGetUserPlatformAccountClosureHistories)

    Get user's platform account closure histories.
    ------
    Supported platforms:
    * psn

    Scope: account

    Required Scope(s):
        - account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/users/platforms/closure/histories

        method: GET

        tags: ["Platform Account Closure History"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        platform: (platform) OPTIONAL str in query

        user_id: (userId) OPTIONAL str in query

    Responses:
        200: OK - DtoUserPlatformAccountClosureHistoriesResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetUserPlatformAccountClosureHistories.create(
        limit=limit,
        offset=offset,
        platform=platform,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Reporting Service."""

__version__ = "0.1.36"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

# admin_configurations
from .wrappers import get
from .wrappers import get_async
from .wrappers import upsert
from .wrappers import upsert_async

# admin_extension_categories_and_auto_moderation_actions
from .wrappers import admin_create_extension_category
from .wrappers import admin_create_extension_category_async
from .wrappers import admin_create_mod_action
from .wrappers import admin_create_mod_action_async
from .wrappers import admin_find_action_list
from .wrappers import admin_find_action_list_async
from .wrappers import admin_find_extension_category_list
from .wrappers import admin_find_extension_category_list_async

# admin_moderation_rule
from .wrappers import create_moderation_rule
from .wrappers import create_moderation_rule_async
from .wrappers import delete_moderation_rule
from .wrappers import delete_moderation_rule_async
from .wrappers import get_moderation_rule_details
from .wrappers import get_moderation_rule_details_async
from .wrappers import get_moderation_rules
from .wrappers import get_moderation_rules_async
from .wrappers import update_moderation_rule
from .wrappers import update_moderation_rule_async
from .wrappers import update_moderation_rule_status
from .wrappers import update_moderation_rule_status_async

# admin_reasons
from .wrappers import admin_get_all_reasons
from .wrappers import admin_get_all_reasons_async
from .wrappers import admin_get_reason
from .wrappers import admin_get_reason_async
from .wrappers import admin_get_reasons
from .wrappers import admin_get_reasons_async
from .wrappers import admin_get_unused_reasons
from .wrappers import admin_get_unused_reasons_async
from .wrappers import admin_list_reason_groups
from .wrappers import admin_list_reason_groups_async
from .wrappers import create_reason
from .wrappers import create_reason_async
from .wrappers import create_reason_group
from .wrappers import create_reason_group_async
from .wrappers import delete_reason
from .wrappers import delete_reason_async
from .wrappers import delete_reason_group
from .wrappers import delete_reason_group_async
from .wrappers import get_reason_group
from .wrappers import get_reason_group_async
from .wrappers import update_reason
from .wrappers import update_reason_async
from .wrappers import update_reason_group
from .wrappers import update_reason_group_async

# admin_reports
from .wrappers import admin_submit_report
from .wrappers import admin_submit_report_async
from .wrappers import list_reports
from .wrappers import list_reports_async

# admin_tickets
from .wrappers import delete_ticket
from .wrappers import delete_ticket_async
from .wrappers import get_reports_by_ticket
from .wrappers import get_reports_by_ticket_async
from .wrappers import get_ticket_detail
from .wrappers import get_ticket_detail_async
from .wrappers import list_tickets
from .wrappers import list_tickets_async
from .wrappers import ticket_statistic
from .wrappers import ticket_statistic_async
from .wrappers import update_ticket_resolutions
from .wrappers import update_ticket_resolutions_async

# public_reasons
from .wrappers import public_get_reasons
from .wrappers import public_get_reasons_async
from .wrappers import public_list_reason_groups
from .wrappers import public_list_reason_groups_async

# public_reports
from .wrappers import submit_report
from .wrappers import submit_report_async
